@@ -3,6 +3,9 @@
 // Use is subject to license terms.
 //
 
+// derive(juniper::GraphQLEnum) triggers this lint
+#![allow(clippy::use_self)]
+
 use serde_with::{DeserializeFromStr, SerializeDisplay};
 
 use super::*;
@@ -12,6 +15,7 @@ mod impls;
 #[derive(
     Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord, Hash, SerializeDisplay, DeserializeFromStr,
 )]
+#[cfg_attr(feature = "graphql", derive(juniper::GraphQLEnum))]
 #[cfg_attr(feature = "jsonschema", derive(schemars::JsonSchema))]
 pub enum AwsRegion {
     ApNortheast1,
