@@ -18,4 +18,12 @@
 #![warn(unused)]
 #![deny(warnings)]
 
+pub mod aws;
+pub mod azure;
 pub mod location;
+
+pub use aws::AwsRegion;
+pub use azure::AzureRegion;
+pub use location::CloudLocation;
+pub use location::InvalidLocation;
+pub use location::Location;
