@@ -6,13 +6,11 @@
 use std::fmt;
 use std::str;
 
-use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
-use serde_with::{DeserializeFromStr, SerializeDisplay};
 use thiserror::Error;
 
-pub mod aws;
-pub mod azure;
+use crate::aws;
+use crate::azure;
 
 pub trait CloudLocation {
     const VENDOR: &'static str;
@@ -20,11 +18,11 @@ pub trait CloudLocation {
     fn as_str(&self) -> &'static str;
 }
 
-#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq, JsonSchema, Serialize, Deserialize)]
+#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq, Serialize, Deserialize)]
+#[cfg_attr(feature = "jsonschema", derive(schemars::JsonSchema))]
 pub enum Location {
     Aws(aws::AwsRegion),
     Azure(azure::AzureRegion),
-    // Gcp(v1::GcpRegion),
 }
 
 impl Location {
